/**
 * <b>Date</b>
 * <p>
 * Creates JavaScript Date instances which let you work with dates and times.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>minute</b></td>
 * <td>Integer value representing the minute segment (0-59) of a time reading.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>second</b></td>
 * <td>Integer value representing the second segment (0-59) of a time reading.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>millisecond</b></td>
 * <td>Integer value representing the millisecond segment (0-999) of a time reading.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>month</b></td>
 * <td>Integer value representing the month, beginning with 0 for January to 11 for December.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>year</b></td>
 * <td>Integer value representing the year. For compatibility (in order to avoid the Y2K problem), you should always specify the year in full; use 1998, rather than 98.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>hour</b></td>
 * <td>Integer value representing the hour of the day (0-23).</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>day</b></td>
 * <td>Integer value representing the day of the month (1-31).</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>dateString</b></td>
 * <td>String value representing a date. The string should be in a format recognized by the parse method (IETF-compliant RFC 2822 timestamps).</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>milliseconds</b></td>
 * <td>Integer value representing the number of milliseconds since 1 January 1970 00:00:00 UTC (Unix Epoch).</td>
 * </tr>
 * </table>
 * @type Date
 */
var Date = {
/**
 * <b>toLocaleDateString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>toLocaleDateString()</code>
 * </p>
 * <p>
 * Converts a date to a string, returning the "date" portion using the operating system's locale's conventions.
 * </p>
 * @type String
 */
toLocaleDateString: function() {},

/**
 * <b>getUTCSeconds</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getUTCSeconds()</code>
 * </p>
 * <p>
 * Returns the seconds in the specified date according to universal time.
 * </p>
 * @type Number
 */
getUTCSeconds: function() {},

/**
 * <b>setYear</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setYear(<i>yearValue</i>)</code>
 * </p>
 * <p>
 * Sets the year for a specified date according to local time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>yearValue </b></td>
 * <td>An integer.</td>
 * </tr>
 * </table>
 * @type Number
 */
setYear: function() {},

/**
 * <b>toUTCString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>toUTCString()</code>
 * </p>
 * <p>
 * Converts a date to a string, using the universal time convention.
 * </p>
 * @type String
 */
toUTCString: function() {},

/**
 * <b>setUTCFullYear</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setUTCFullYear(<em>yearValue</em>[,<em>monthValue</em>[,<em>dayValue</em>]])</code>
 * </p>
 * <p>
 * Sets the full year for a specified date according to universal time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>monthValue </b></td>
 * <td>An integer between 0 and 11 representing the months January through December.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>dayValue </b></td>
 * <td>An integer between 1 and 31 representing the day of the month. If you specify the dayValue parameter, you must also specify the monthValue.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>yearValue </b></td>
 * <td>An integer specifying the numeric value of the year, for example, 1995.</td>
 * </tr>
 * </table>
 * @type Number
 */
setUTCFullYear: function() {},

/**
 * <b>getTimezoneOffset</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getTimezoneOffset()</code>
 * </p>
 * <p>
 * Returns the time-zone offset from UTC, in minutes, for the current locale.
 * </p>
 * @type Number
 */
getTimezoneOffset: function() {},

/**
 * <b>getDay</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getDay()</code>
 * </p>
 * <p>
 * Returns the day of the week for the specified date according to local time.
 * </p>
 * @type Number
 */
getDay: function() {},

/**
 * <b>setUTCHours</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setUTCHours(<em>hoursValue</em>[,<em>minutesValue</em>[,<em>secondsValue</em>[,<em>msValue</em>]]])</code>
 * </p>
 * <p>
 * Sets the hour for a specified date according to universal time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>hoursValue </b></td>
 * <td>An integer between 0 and 23, representing the hour.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>msValue </b></td>
 * <td>A number between 0 and 999, representing the milliseconds. If you specify the msValue parameter, you must also specify the minutesValue and secondsValue.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>secondsValue </b></td>
 * <td>An integer between 0 and 59, representing the seconds. If you specify the secondsValue parameter, you must also specify the minutesValue.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>minutesValue </b></td>
 * <td>An integer between 0 and 59, representing the minutes.</td>
 * </tr>
 * </table>
 * @type Number
 */
setUTCHours: function() {},

/**
 * <b>getYear</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getYear()</code>
 * </p>
 * <p>
 * Returns the year in the specified date according to local time.
 * </p>
 * @type Number
 */
getYear: function() {},

/**
 * <b>prototype</b>
 * <p>
 * Represents the prototype for the Date constructor.
 * </p>
 * @type Number
 * @static
 */
prototype: undefined,

/**
 * <b>setMinutes</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setMinutes(<i>minutesValue</i>[,<i>secondsValue</i>[,<em>msValue</em>]])</code>
<code>setMinutes(<i>minutesValue</i>)</code>
 * </p>
 * <p>
 * Sets the minutes for a specified date according to local time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>msValue </b></td>
 * <td>A number between 0 and 999, representing the milliseconds. If you specify the msValue parameter, you must also specify the minutesValue and secondsValue.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>secondsValue </b></td>
 * <td>An integer between 0 and 59, representing the seconds. If you specify the secondsValue parameter, you must also specify the minutesValue.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>minutesValue </b></td>
 * <td>An integer between 0 and 59, representing the minutes.</td>
 * </tr>
 * </table>
 * @type Number
 */
setMinutes: function() {},

/**
 * <b>toISOString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>myDate.toISOString()</code>
 * </p>
 * <p>
 * JavaScript provides a direct way to convert a date object into a string in ISO format, the ISO 8601 Extended Format. The Date.prototype.toISOString is an ECMAScript 5 addition. Format is as follows: YYYY-MM-DDTHH:mm:ss.sssZ
 * </p>
 * @type String
 */
toISOString: function() {},

/**
 * <b>setMilliseconds</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setMilliseconds(<em>millisecondsValue</em>)</code>
 * </p>
 * <p>
 * Sets the milliseconds for a specified date according to local time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>millisecondsValue </b></td>
 * <td>A number between 0 and 999, representing the milliseconds.</td>
 * </tr>
 * </table>
 * @type Number
 */
setMilliseconds: function() {},

/**
 * <b>UTC</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Date.UTC(<i>year</i>,<i>month</i>[,<i>date</i>[,<i>hrs</i>[,<i>min</i>[,<i>sec</i>[,<em>ms</em>]]]]])</code>
 * </p>
 * <p>
 * Accepts the same parameters as the longest form of the constructor, and returns the number of milliseconds in a Date object since January 1, 1970, 00:00:00, universal time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>hrs </b></td>
 * <td>An integer between 0 and 23 representing the hours.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>date </b></td>
 * <td>An integer between 1 and 31 representing the day of the month.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>year </b></td>
 * <td>A year after 1900.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>ms </b></td>
 * <td>An integer between 0 and 999 representing the milliseconds.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>sec </b></td>
 * <td>An integer between 0 and 59 representing the seconds.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>min </b></td>
 * <td>An integer between 0 and 59 representing the minutes.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>month </b></td>
 * <td>An integer between 0 and 11 representing the month.</td>
 * </tr>
 * </table>
 * @type Number
 * @static
 */
UTC: function() {},

/**
 * <b>getUTCDate</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getUTCDate()</code>
 * </p>
 * <p>
 * Returns the day (date) of the month in the specified date according to universal time.
 * </p>
 * @type Number
 */
getUTCDate: function() {},

/**
 * <b>toTimeString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>date</em>.toTimeString()</code>
 * </p>
 * @type String
 */
toTimeString: function() {},

/**
 * <b>setSeconds</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setSeconds(<i>secondsValue</i>[,<em>msValue</em>])</code>
<code>setSeconds(<i>secondsValue</i>)</code>
 * </p>
 * <p>
 * Sets the seconds for a specified date according to local time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>msValue </b></td>
 * <td>A number between 0 and 999, representing the milliseconds.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>secondsValue </b></td>
 * <td>An integer between 0 and 59.</td>
 * </tr>
 * </table>
 * @type Number
 */
setSeconds: function() {},

/**
 * <b>setUTCSeconds</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setUTCSeconds(<em>secondsValue</em>[,<em>msValue</em>])</code>
 * </p>
 * <p>
 * Sets the seconds for a specified date according to universal time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>msValue </b></td>
 * <td>A number between 0 and 999, representing the milliseconds.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>secondsValue </b></td>
 * <td>An integer between 0 and 59.</td>
 * </tr>
 * </table>
 * @type Number
 */
setUTCSeconds: function() {},

/**
 * <b>toDateString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>date</em>.toDateString()</code>
 * </p>
 * <p>
 * Returns the date portion of a Date object in human readable form in American English.
 * </p>
 * @type String
 */
toDateString: function() {},

/**
 * <b>getDate</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getDate()</code>
 * </p>
 * <p>
 * Returns the day of the month for the specified date according to local time.
 * </p>
 * @type Number
 */
getDate: function() {},

/**
 * <b>setHours</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setHours(<i>hoursValue</i>[,<i>minutesValue</i>[,<i>secondsValue</i>[,<em>msValue</em>]]])</code>
<code>setHours(<i>hoursValue</i>)</code>
 * </p>
 * <p>
 * Sets the hours for a specified date according to local time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>hoursValue </b></td>
 * <td>An integer between 0 and 23, representing the hour.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>msValue </b></td>
 * <td>A number between 0 and 999, representing the milliseconds. If you specify the msValue parameter, you must also specify the minutesValue and secondsValue.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>secondsValue </b></td>
 * <td>An integer between 0 and 59, representing the seconds. If you specify the secondsValue parameter, you must also specify the minutesValue.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>minutesValue </b></td>
 * <td>An integer between 0 and 59, representing the minutes.</td>
 * </tr>
 * </table>
 * @type Number
 */
setHours: function() {},

/**
 * <b>now</b>
 * @type Number
 * @static
 */
now: function() {},

/**
 * <b>getUTCFullYear</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getUTCFullYear()</code>
 * </p>
 * <p>
 * Returns the year in the specified date according to universal time.
 * </p>
 * @type Number
 */
getUTCFullYear: function() {},

/**
 * <b>getMonth</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getMonth()</code>
 * </p>
 * <p>
 * Returns the month in the specified date according to local time.
 * </p>
 * @type Number
 */
getMonth: function() {},

/**
 * <b>toString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>toString()</code>
 * </p>
 * <p>
 * Returns a string representing the specified Date object.
 * </p>
 * @type String
 */
toString: function() {},

/**
 * <b>setUTCDate</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setUTCDate(<em>dayValue</em>)</code>
 * </p>
 * <p>
 * Sets the day of the month for a specified date according to universal time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>dayValue </b></td>
 * <td>An integer from 1 to 31, representing the day of the month.</td>
 * </tr>
 * </table>
 * @type Number
 */
setUTCDate: function() {},

/**
 * <b>setUTCMonth</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setUTCMonth(<em>monthValue</em>[,<em>dayValue</em>])</code>
 * </p>
 * <p>
 * Sets the month for a specified date according to universal time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>monthValue </b></td>
 * <td>An integer between 0 and 11, representing the months January through December.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>dayValue </b></td>
 * <td>An integer from 1 to 31, representing the day of the month.</td>
 * </tr>
 * </table>
 * @type Number
 */
setUTCMonth: function() {},

/**
 * <b>getMinutes</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getMinutes()</code>
 * </p>
 * <p>
 * Returns the minutes in the specified date according to local time.
 * </p>
 * @type Number
 */
getMinutes: function() {},

/**
 * <b>toLocaleString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>toLocaleString()</code>
 * </p>
 * <p>
 * Converts a date to a string, using the operating system's locale's conventions.
 * </p>
 * @type String
 */
toLocaleString: function() {},

/**
 * <b>toSource</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>date</em>.toSource()</code>
 * </p>
 * <p>
 * Returns a string representing the source code of the object.
 * </p>
 * @type String
 */
toSource: function() {},

/**
 * <b>getSeconds</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getSeconds()</code>
 * </p>
 * <p>
 * Returns the seconds in the specified date according to local time.
 * </p>
 * @type Number
 */
getSeconds: function() {},

/**
 * <b>getUTCMonth</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getUTCMonth()</code>
 * </p>
 * <p>
 * Returns the month of the specified date according to universal time.
 * </p>
 * @type Number
 */
getUTCMonth: function() {},

/**
 * <b>getFullYear</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getFullYear()</code>
 * </p>
 * <p>
 * Returns the year of the specified date according to local time.
 * </p>
 * @type Number
 */
getFullYear: function() {},

/**
 * <b>getHours</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getHours()</code>
 * </p>
 * <p>
 * Returns the hour for the specified date according to local time.
 * </p>
 * @type Number
 */
getHours: function() {},

/**
 * <b>getUTCHours</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getUTCHours</code>
 * </p>
 * <p>
 * Returns the hours in the specified date according to universal time.
 * </p>
 * @type Number
 */
getUTCHours: function() {},

/**
 * <b>toLocaleFormat</b>
 * <p>
 * Converts a date to a string using the specified formatting.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>formatString </b></td>
 * <td>A format string in the same format expected by the strftime() function in C.</td>
 * </tr>
 * </table>
 * @type Number
 */
toLocaleFormat: function() {},

/**
 * <b>valueOf</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>valueOf()</code>
 * </p>
 * <p>
 * Returns the primitive value of a Date object.
 * </p>
 * @type Number
 */
valueOf: function() {},

/**
 * <b>parse</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Date.parse(dateString)</code>
 * </p>
 * <p>
 * Parses a string representation of a date, and returns the number of milliseconds since January 1, 1970, 00:00:00 UTC.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>dateString</b></td>
 * <td>A string representing an RFC2822 or ISO 8601 date.</td>
 * </tr>
 * </table>
 * @type Number
 * @static
 */
parse: function() {},

/**
 * <b>constructor</b>
 * <p>
 * Returns a reference to the Date function that created the instance's prototype. Note that the value of this property is a reference to the function itself, not a string containing the function's name.
 * </p>
 * @type Function
 */
constructor: undefined,

/**
 * <b>setTime</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setTime(<em>timeValue</em>)</code>
 * </p>
 * <p>
 * Sets the Date object to the time represented by a number of milliseconds since January 1, 1970, 00:00:00 UTC.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>timeValue </b></td>
 * <td>An integer representing the number of milliseconds since 1 January 1970, 00:00:00 UTC.</td>
 * </tr>
 * </table>
 * @type Number
 */
setTime: function() {},

/**
 * <b>toLocaleTimeString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>toLocaleTimeString()</code>
 * </p>
 * <p>
 * Converts a date to a string, returning the "time" portion using the current locale's conventions.
 * </p>
 * @type String
 */
toLocaleTimeString: function() {},

/**
 * <b>setUTCMilliseconds</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setUTCMilliseconds(<em>millisecondsValue</em>)</code>
 * </p>
 * <p>
 * Sets the milliseconds for a specified date according to universal time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>millisecondsValue </b></td>
 * <td>A number between 0 and 999, representing the milliseconds.</td>
 * </tr>
 * </table>
 * @type Number
 */
setUTCMilliseconds: function() {},

/**
 * <b>setUTCMinutes</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setUTCMinutes(<em>minutesValue</em>[,<em>secondsValue</em>[,<em>msValue</em>]])</code>
 * </p>
 * <p>
 * Sets the minutes for a specified date according to universal time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>msValue </b></td>
 * <td>A number between 0 and 999, representing the milliseconds. If you specify the msValue parameter, you must also specify the minutesValue and secondsValue.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>secondsValue </b></td>
 * <td>An integer between 0 and 59, representing the seconds. If you specify the secondsValue parameter, you must also specify the minutesValue.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>minutesValue </b></td>
 * <td>An integer between 0 and 59, representing the minutes.</td>
 * </tr>
 * </table>
 * @type Number
 */
setUTCMinutes: function() {},

/**
 * <b>setMonth</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setMonth(<i>monthValue</i>[,<em>dayValue</em>])</code>
<code>setMonth(<i>monthValue</i>)</code>
 * </p>
 * <p>
 * Set the month for a specified date according to local time.
 * </p>
 * @type Number
 */
setMonth: function() {},

/**
 * <b>setDate</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setDate(<em>dayValue</em>)</code>
 * </p>
 * <p>
 * Sets the day of the month for a specified date according to local time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>dayValue </b></td>
 * <td>An integer from 1 to 31, representing the day of the month.</td>
 * </tr>
 * </table>
 * @type Number
 */
setDate: function() {},

/**
 * <b>getUTCMinutes</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getUTCMinutes()</code>
 * </p>
 * <p>
 * Returns the minutes in the specified date according to universal time.
 * </p>
 * @type Number
 */
getUTCMinutes: function() {},

/**
 * <b>setFullYear</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>setFullYear(<em>yearValue</em>[,<em>monthValue</em>[,<em>dayValue</em>]])</code>
 * </p>
 * <p>
 * Sets the full year for a specified date according to local time.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>monthValue </b></td>
 * <td>An integer between 0 and 11 representing the months January through December.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>dayValue </b></td>
 * <td>An integer between 1 and 31 representing the day of the month. If you specify the dayValue parameter, you must also specify the monthValue.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>yearValue </b></td>
 * <td>An integer specifying the numeric value of the year, for example, 1995.</td>
 * </tr>
 * </table>
 * @type Number
 */
setFullYear: function() {},

/**
 * <b>getTime</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getTime()</code>
 * </p>
 * <p>
 * Returns the numeric value corresponding to the time for the specified date according to universal time.
 * </p>
 * @type Number
 */
getTime: function() {},

/**
 * <b>toJSON</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>date</em>.toJSON()</code>
 * </p>
 * <p>
 * Returns a JSON representation of the Date object.
 * </p>
 * @type Number
 */
toJSON: function() {},

/**
 * <b>getUTCDay</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getUTCDay()</code>
 * </p>
 * <p>
 * Returns the day of the week in the specified date according to universal time.
 * </p>
 * @type Number
 */
getUTCDay: function() {},

/**
 * <b>toGMTString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>toGMTString()</code>
 * </p>
 * <p>
 * Converts a date to a string, using Internet GMT conventioins.
 * </p>
 * @type String
 */
toGMTString: function() {},

/**
 * <b>getUTCMilliseconds</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getUTCMilliseconds()</code>
 * </p>
 * <p>
 * Returns the milliseconds in the specified date according to universal time.
 * </p>
 * @type Number
 */
getUTCMilliseconds: function() {},

/**
 * <b>getMilliseconds</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>getMilliseconds()</code>
 * </p>
 * <p>
 * Returns the milliseconds in the specified date according to local time.
 * </p>
 * @type Number
 */
getMilliseconds: function() {},

}
