/**
 * <b>RegExp</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>RegExp(<em>pattern</em><em>[,flags]</em>)</code><br/><code>/<em>pattern</em>/<em>flags</em></code>
 * </p>
 * <p>
 * Creates a regular expression object for matching text with a pattern.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>flags</b></td>
 * <td></td>
 * </tr>
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>pattern</b></td>
 * <td>The text of the regular expression.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>g i m</b></td>
 * <td>global match ignore case Treat beginning and end characters (^ and $) as working over multiple lines (i.e., match the beginning or end of each line (delimited by \n or \r), not only the very beginning or end of the whole input string)</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>y</b></td>
 * <td>New in Firefox 3 Non-standard sticky; matches only from the index indicated by the lastIndex property of this regular expression in the target string (and does not attempt to match from any later indexes). This allows the match-only-at-start capabilities of the character "^" to effectively be used at any location in a string by changing the value of the lastIndex property.</td>
 * </tr>
 * </table>
 * @type RegExp
 */
var RegExp = {
/**
 * <b>lastIndex</b>
 * <p>
 * A read/write integer property that specifies the index at which to start the next match. JavaScript 1.5: lastIndex is a property of a RegExp instance, not the RegExp object.
 * </p>
 * @type Number
 */
lastIndex: undefined,

/**
 * <b>toSource</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>regexp</em>.toSource()</code>
 * </p>
 * <p>
 * Returns a string representing the source code of the object.
 * </p>
 * @type String
 */
toSource: function() {},

/**
 * <b>sticky</b>
 * @type Boolean
 */
sticky: undefined,

/**
 * <b>source</b>
 * <p>
 * A read-only property that contains the text of the pattern, excluding the forward slashes. Static JavaScript 1.5: source is a property of a RegExp instance, not the RegExp object.
 * </p>
 * @type String
 */
source: undefined,

/**
 * <b>test</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>regexp</em>.test([<em>str</em>])</code>
 * </p>
 * <p>
 * Executes the search for a match between a regular expression and a specified string. Returns true or false.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>str</b></td>
 * <td>The string against which to match the regular expression.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>regexp</b></td>
 * <td>The name of the regular expression. It can be a variable name or a literal.</td>
 * </tr>
 * </table>
 * @type Boolean
 */
test: function() {},

/**
 * <b>multiline</b>
 * <p>
 * Reflects whether or not to search in strings across multiple lines. Static JavaScript 1.5: multiline is a property of a RegExp instance, not the RegExp object.
 * </p>
 * @type Boolean
 */
multiline: undefined,

/**
 * <b>global</b>
 * <p>
 * Whether or not the "g" flag is used with the regular expression. Read-only JavaScript 1.5: global is a property of a RegExp instance, not the RegExp object.
 * </p>
 * @type Boolean
 */
global: undefined,

/**
 * <b>toString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>regexp</em>.toString()</code>
 * </p>
 * <p>
 * Returns a string representing the specified object.
 * </p>
 * @type String
 */
toString: function() {},

/**
 * <b>exec</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>result</em>=<em>regexp</em>.exec(<em>str</em>)</code>
 * </p>
 * <p>
 * Executes a search for a match in a specified string. Returns a result array, or null.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>str</b></td>
 * <td>The string against which to match the regular expression.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>regexp</b></td>
 * <td>The name of the regular expression. It can be a variable name or a literal.</td>
 * </tr>
 * </table>
 * @type Array
 */
exec: function() {},

/**
 * <b>ignoreCase</b>
 * <p>
 * Whether or not the "i" flag is used with the regular expression. JavaScript 1.5: ignoreCase is a property of a RegExp instance, not the RegExp object.
 * </p>
 * @type Boolean
 */
ignoreCase: undefined,

/**
 * <b>prototype</b>
 * <p>
 * Represents the prototype object for the RegExp constructor.
 * </p>
 * @type Object
 * @static
 */
prototype: undefined,

/**
 * <b>constructor</b>
 * <p>
 * Returns a reference to the RegExp function that created the instance's prototype. Note that the value of this property is a reference to the function itself, not a string containing the function's name.
 * </p>
 * @type Function
 */
constructor: undefined,

}
